<?php if ( ! defined('BASEPATH')) exit('Invalid file request.');

/**
 * OmniLog Entry tests.
 *
 * @author          Stephen Lewis (http://github.com/experience/)
 * @copyright       Experience Internet
 * @package         Omnilog
 */

require_once dirname(__FILE__) .'/../classes/omnilog_entry.php';

class Test_omnilog_entry extends Testee_unit_test_case {

  private $_props;
  private $_subject;


  /* --------------------------------------------------------------
   * PUBLIC METHODS
   * ------------------------------------------------------------ */

  /**
   * Constructor.
   *
   * @access  public
   * @return  void
   */
  public function setUp()
  {
    parent::setUp();

    $this->_props = array(
      'addon_name'    => 'Example Add-on',
      'admin_emails'  => array('adam@ants.com', 'bob@dylan.com'),
      'date'          => time() - 1000,
      'log_entry_id'  => 100,
      'message'       => 'Example log entry.',
      'extended_data' => 'Example extended data.',
      'notify_admin'  => TRUE,
      'type'          => Omnilog_entry::WARNING
    );

    $this->EE->email->setReturnValue('valid_email', TRUE);
    $this->_subject = new Omnilog_entry($this->_props);
  }


  public function test__constructor__success()
  {
    foreach ($this->_props AS $prop_name => $prop_value)
    {
      $method_name = 'get_' .$prop_name;
      $this->assertIdentical($prop_value, $this->_subject->$method_name());
    }
  }


  public function test__admin_emails__no_admin_emails()
  {
    unset($this->_props['admin_emails']);
    $subject = new Omnilog_entry($this->_props);

    $this->assertIdentical(array(), $subject->get_admin_emails());
  }


  public function test__constructor__unknown_property()
  {
    // If this doesn't throw an error, it's worked.
    $props = array_merge($this->_props, array('dummy_property' => 'invalid'));
    new Omnilog_entry($props);
  }


  public function test__is_populated__populated_without_entry_id()
  {
    unset($this->_props['log_entry_id']);
    $subject = new Omnilog_entry($this->_props);
    $this->assertIdentical(TRUE, $subject->is_populated());
  }


  public function test__is_populated__populated_with_entry_id()
  {
    $this->assertIdentical(TRUE, $this->_subject->is_populated(TRUE));
  }


  public function test__is_populated__not_populated_without_entry_id()
  {
    unset($this->_props['log_entry_id']);

    // Add-on name.
    $props = array_merge($this->_props, array('addon_name' => ''));
    $subject = new Omnilog_entry($props);
    $this->assertIdentical(FALSE, $subject->is_populated());

    // Date.
    $props = array_merge($this->_props, array('date' => 0));
    $subject = new Omnilog_entry($props);
    $this->assertIdentical(FALSE, $subject->is_populated());

    // Message.
    $props = array_merge($this->_props, array('message' => ''));
    $subject = new Omnilog_entry($props);
    $this->assertIdentical(FALSE, $subject->is_populated());

    // Type.
    $props = array_merge($this->_props, array('type' => 0));
    $subject = new Omnilog_entry($props);
    $this->assertIdentical(FALSE, $subject->is_populated());
  }


  public function test__is_populated__not_populated_with_entry_id()
  {
    unset($this->_props['log_entry_id']);
    $subject = new Omnilog_entry($this->_props);
    $this->assertIdentical(FALSE, $subject->is_populated(TRUE));
  }


  public function test__reset__success()
  {
    $result = $this->_subject->reset();

    $this->assertIdentical('', $result->get_addon_name());
    $this->assertIdentical(array(), $result->get_admin_emails());
    $this->assertIdentical(0, $result->get_date());
    $this->assertIdentical(0, $result->get_log_entry_id());
    $this->assertIdentical('', $result->get_message());        
    $this->assertIdentical('', $result->get_extended_data());
    $this->assertIdentical(FALSE, $result->get_notify_admin());
    $this->assertIdentical(Omnilog_entry::NOTICE, $result->get_type());
  }


  public function test__set_addon_name__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['addon_name'];

    $this->assertIdentical($v, $s->set_addon_name(123));
    $this->assertIdentical($v, $s->set_addon_name(FALSE));
    $this->assertIdentical($v, $s->set_addon_name(new StdClass()));
    $this->assertIdentical($v, $s->set_addon_name(NULL));
  }


  public function test__set_admin_emails__invalid_emails()
  {
    $invalid_email  = 'bob';
    $valid_email    = 'bob@bob.com';

    $this->EE->email->setReturnValueAt(2, 'valid_email', FALSE);
    $this->EE->email->setReturnValueAt(3, 'valid_email', TRUE);

    $this->assertIdentical(array($valid_email),
      $this->_subject->set_admin_emails(array($invalid_email, $valid_email)));
  }


  public function test__set_date__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['date'];

    $this->assertIdentical($v, $s->set_date('Invalid'));
    $this->assertIdentical($v, $s->set_date(FALSE));
    $this->assertIdentical($v, $s->set_date(new StdClass()));
    $this->assertIdentical($v, $s->set_date(NULL));
    $this->assertIdentical($v, $s->set_date(time() + 100));
    $this->assertIdentical($v, $s->set_date(-100));
  }


  public function test__set_log_entry_id__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['log_entry_id'];

    $this->assertIdentical($v, $s->set_log_entry_id('Invalid'));
    $this->assertIdentical($v, $s->set_log_entry_id(FALSE));
    $this->assertIdentical($v, $s->set_log_entry_id(new StdClass()));
    $this->assertIdentical($v, $s->set_log_entry_id(NULL));
    $this->assertIdentical($v, $s->set_log_entry_id(0));
  }


  public function test__set_message__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['message'];

    $this->assertIdentical($v, $s->set_message(123));
    $this->assertIdentical($v, $s->set_message(FALSE));
    $this->assertIdentical($v, $s->set_message(new StdClass()));
    $this->assertIdentical($v, $s->set_message(NULL));
  }


  public function test__set_extended_data__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['extended_data'];

    $this->assertIdentical($v, $s->set_extended_data(123));
    $this->assertIdentical($v, $s->set_extended_data(FALSE));
    $this->assertIdentical($v, $s->set_extended_data(new StdClass()));
    $this->assertIdentical($v, $s->set_extended_data(NULL));
  }


  public function test__set_notify_admin__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['notify_admin'];

    $this->assertIdentical($v, $s->set_notify_admin(123));
    $this->assertIdentical($v, $s->set_notify_admin('Invalid'));
    $this->assertIdentical($v, $s->set_notify_admin(new StdClass()));
    $this->assertIdentical($v, $s->set_notify_admin(NULL));
  }


  public function test__set_type__invalid_values()
  {
    $s = $this->_subject;
    $v = $this->_props['type'];

    $this->assertIdentical($v, $s->set_type('Invalid'));
    $this->assertIdentical($v, $s->set_type(FALSE));
    $this->assertIdentical($v, $s->set_type(new StdClass()));
    $this->assertIdentical($v, $s->set_type(NULL));
    $this->assertIdentical($v, $s->set_type(20));
  }


  public function test__to_array__success_without_entry_id()
  {
    unset($this->_props['log_entry_id']);
    $this->assertIdentical($this->_props, $this->_subject->to_array());
  }


  public function test__to_array__success_with_entry_id()
  {
    $result = $this->_subject->to_array(TRUE);

    ksort($result);
    ksort($this->_props);

    $this->assertIdentical($this->_props, $result);
  }


}


/* End of file      : test.omnilog_entry.php */
/* File location    : third_party/omnilog/tests/test.omnilog_entry.php */
